import _objectSpread from '@babel/runtime/helpers/objectSpread2';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import { getCoreRowModel, getSortedRowModel, getFacetedRowModel, getFacetedUniqueValues, getFacetedMinMaxValues, getFilteredRowModel, getPaginationRowModel, useReactTable } from '@tanstack/react-table';
import { useEds, Table, Pagination } from '@equinor/eds-core-react';
import { useState, useEffect, useMemo, useRef, useCallback } from 'react';
import { TableHeaderRow } from './components/TableHeaderRow.js';
import { TableRow } from './components/TableRow.js';
import { TableProvider } from './EdsDataGridContext.js';
import { useVirtualizer } from '@tanstack/react-virtual';
import { jsxs, jsx, Fragment } from 'react/jsx-runtime';

function EdsDataGrid(_ref) {
  var rows = _ref.rows,
    columns = _ref.columns,
    columnResizeMode = _ref.columnResizeMode,
    pageSize = _ref.pageSize,
    rowSelection = _ref.rowSelection,
    selectedRows = _ref.selectedRows,
    enableColumnFiltering = _ref.enableColumnFiltering,
    debug = _ref.debug,
    enablePagination = _ref.enablePagination,
    enableSorting = _ref.enableSorting,
    stickyHeader = _ref.stickyHeader,
    onSelectRow = _ref.onSelectRow,
    caption = _ref.caption,
    enableVirtual = _ref.enableVirtual,
    virtualHeight = _ref.virtualHeight,
    columnVisibility = _ref.columnVisibility,
    columnVisibilityChange = _ref.columnVisibilityChange,
    emptyMessage = _ref.emptyMessage,
    columnOrder = _ref.columnOrder,
    cellClass = _ref.cellClass,
    cellStyle = _ref.cellStyle,
    rowClass = _ref.rowClass,
    rowStyle = _ref.rowStyle,
    headerClass = _ref.headerClass,
    headerStyle = _ref.headerStyle;
  var _useState = useState([]),
    _useState2 = _slicedToArray(_useState, 2),
    sorting = _useState2[0],
    setSorting = _useState2[1];
  var _useState3 = useState(selectedRows !== null && selectedRows !== void 0 ? selectedRows : {}),
    _useState4 = _slicedToArray(_useState3, 2),
    selection = _useState4[0],
    setSelection = _useState4[1];
  var _useState5 = useState([]),
    _useState6 = _slicedToArray(_useState5, 2),
    columnFilters = _useState6[0],
    setColumnFilters = _useState6[1];
  var _useState7 = useState(columnVisibility !== null && columnVisibility !== void 0 ? columnVisibility : {}),
    _useState8 = _slicedToArray(_useState7, 2),
    visible = _useState8[0],
    setVisible = _useState8[1];
  var _useState9 = useState(''),
    _useState10 = _slicedToArray(_useState9, 2),
    globalFilter = _useState10[0],
    setGlobalFilter = _useState10[1];
  var _useState11 = useState([]),
    _useState12 = _slicedToArray(_useState11, 2),
    columnOrderState = _useState12[0],
    setColumnOrderState = _useState12[1];
  var _useState13 = useState({
      pageIndex: 0,
      pageSize: pageSize !== null && pageSize !== void 0 ? pageSize : 25
    }),
    _useState14 = _slicedToArray(_useState13, 2),
    page = _useState14[0],
    setPage = _useState14[1];
  useEffect(function () {
    setVisible(columnVisibility !== null && columnVisibility !== void 0 ? columnVisibility : {});
  }, [columnVisibility, setVisible]);
  useEffect(function () {
    setSelection(selectedRows !== null && selectedRows !== void 0 ? selectedRows : {});
  }, [selectedRows]);

  /**
   * By default, the filter-function accepts single-value filters. This adds multi-filter functionality out of the box.
   */
  var _columns = useMemo(function () {
    return columns.map(function (column) {
      if (column.filterFn || column.enableColumnFilter === false) {
        return column;
      }
      /* istanbul ignore next */
      return _objectSpread(_objectSpread({}, column), {}, {
        filterFn: function filterFn(row, columnId, filterValue) {
          var _row$getValue;
          if (debug) {
            console.log('filterFn', row, columnId, filterValue);
          }
          if (!filterValue || (Array.isArray(filterValue) || typeof filterValue === 'string') && filterValue.length === 0) {
            return true;
          }
          var value = (_row$getValue = row.getValue(columnId)) !== null && _row$getValue !== void 0 ? _row$getValue : 'NULL_OR_UNDEFINED';
          if (Array.isArray(filterValue)) {
            var numeric = filterValue.some(function (v) {
              return typeof v === 'number';
            });
            if (numeric) {
              var _ref2 = filterValue,
                _ref3 = _slicedToArray(_ref2, 2),
                start = _ref3[0],
                end = _ref3[1];
              return value >= (isNaN(start) ? 0 : start) && value <= (!end || isNaN(end) ? Infinity : end);
            } else {
              var validFilterValue = filterValue.filter(function (v) {
                return !!v;
              });
              if (validFilterValue.length === 0) return true;
              return filterValue.includes(value);
            }
          }
          return value === filterValue;
        }
      });
    });
  }, [debug, columns]);

  /**
   * Set up default table options
   */
  var options = {
    data: rows,
    columns: _columns,
    columnResizeMode: columnResizeMode,
    state: {
      sorting: sorting,
      rowSelection: selection,
      columnOrder: columnOrderState
    },
    onSortingChange: setSorting,
    enableColumnFilters: !!enableColumnFiltering,
    enableFilters: !!enableColumnFiltering,
    enableSorting: enableSorting !== null && enableSorting !== void 0 ? enableSorting : false,
    enableColumnResizing: !!columnResizeMode,
    getCoreRowModel: getCoreRowModel(),
    getSortedRowModel: getSortedRowModel(),
    debugTable: debug,
    debugHeaders: debug,
    debugColumns: debug,
    enableRowSelection: rowSelection !== null && rowSelection !== void 0 ? rowSelection : false
  };
  useEffect(function () {
    if (columnOrder && columnOrder.length > 0) {
      setColumnOrderState(columnOrder !== null && columnOrder !== void 0 ? columnOrder : []);
    }
  }, [columnOrder]);

  /**
   * Set up handlers for rowSelection
   */
  if (rowSelection !== null && rowSelection !== void 0 ? rowSelection : false) {
    options.onRowSelectionChange = function (updaterOrValue) {
      if (onSelectRow) {
        onSelectRow(updaterOrValue);
      }
      setSelection(updaterOrValue);
    };
  }

  /**
   * Set up config for column filtering
   */
  if (enableColumnFiltering) {
    options.state.columnFilters = columnFilters;
    options.state.globalFilter = globalFilter;
    options.onColumnFiltersChange = setColumnFilters;
    options.onGlobalFilterChange = setGlobalFilter;
    options.getFacetedRowModel = getFacetedRowModel();
    options.getFacetedUniqueValues = getFacetedUniqueValues();
    options.getFacetedMinMaxValues = getFacetedMinMaxValues();
    options.getFilteredRowModel = getFilteredRowModel();
  }

  /**
   * Set up config for pagination
   */
  if (enablePagination !== null && enablePagination !== void 0 ? enablePagination : false) {
    options.state.pagination = page;
    options.getPaginationRowModel = getPaginationRowModel();
  }

  /**
   * Set up config to handle column visibility controls
   */
  if (columnVisibility) {
    options.state.columnVisibility = visible;
    options.onColumnVisibilityChange = function (vis) {
      var updated;
      if (typeof vis === 'function') {
        updated = vis(visible);
      } else {
        updated = vis;
      }
      if (columnVisibilityChange) columnVisibilityChange(updated);
      setVisible(updated);
    };
  }
  useEffect(function () {
    setPage(function (prev) {
      return _objectSpread(_objectSpread({}, prev), {}, {
        pageSize: pageSize !== null && pageSize !== void 0 ? pageSize : 25
      });
    });
  }, [pageSize]);
  var table = useReactTable(options);
  var parentRefStyle = {};

  /**
   * Style the parent container to enable virtualization.
   * By not setting this, the virtual-scroll will always render every row, reducing computational overhead if turned off.
   */
  if (enableVirtual) {
    parentRefStyle = {
      height: virtualHeight !== null && virtualHeight !== void 0 ? virtualHeight : 500,
      overflow: 'auto',
      position: 'relative'
    };
  }
  var parentRef = useRef(null);

  /**
   * Virtualization setup
   */
  var _useEds = useEds(),
    density = _useEds.density;
  var estimateSize = useCallback(function () {
    return density === 'compact' ? 32 : 48;
  }, [density]);
  var virtualizer = useVirtualizer({
    count: table.getRowModel().rows.length,
    getScrollElement: function getScrollElement() {
      return parentRef.current;
    },
    estimateSize: estimateSize
  });
  var virtualRows = virtualizer.getVirtualItems();
  var paddingTop = virtualRows.length ? virtualRows[0].start : 0;
  var paddingBottom = virtualRows.length ? virtualizer.getTotalSize() - virtualRows[virtualRows.length - 1].end : 0;

  // These classes are primarily used to allow for feature-detection in the test-suite
  var classList = {
    'sticky-header': !!stickyHeader,
    virtual: !!enableVirtual,
    paging: !!enablePagination
  };
  return /*#__PURE__*/jsxs(TableProvider, {
    cellClass: cellClass,
    cellStyle: cellStyle,
    rowClass: rowClass,
    rowStyle: rowStyle,
    headerClass: headerClass,
    headerStyle: headerStyle,
    table: table,
    enableSorting: !!enableSorting,
    enableColumnFiltering: !!enableColumnFiltering,
    stickyHeader: !!stickyHeader,
    children: [/*#__PURE__*/jsxs("div", {
      className: "table-wrapper",
      style: parentRefStyle,
      ref: parentRef,
      children: [/*#__PURE__*/jsxs(Table, {
        className: Object.entries(classList).filter(function (_ref4) {
          var _ref5 = _slicedToArray(_ref4, 2),
            k = _ref5[1];
          return k;
        }).map(function (_ref6) {
          var _ref7 = _slicedToArray(_ref6, 1),
            k = _ref7[0];
          return k;
        }).join(' '),
        style: {
          width: table.getTotalSize()
        },
        children: [caption && /*#__PURE__*/jsx(Table.Caption, {
          children: caption
        }), /*#__PURE__*/jsx(Table.Head, {
          sticky: stickyHeader,
          children: table.getHeaderGroups().map(function (headerGroup) {
            return /*#__PURE__*/jsx(TableHeaderRow, {
              table: table,
              headerGroup: headerGroup,
              columnResizeMode: columnResizeMode,
              deltaOffset: table.getState().columnSizingInfo.deltaOffset
            }, headerGroup.id);
          })
        }), /*#__PURE__*/jsxs(Table.Body, {
          children: [table.getRowModel().rows.length === 0 && emptyMessage && /*#__PURE__*/jsx(Table.Row, {
            children: /*#__PURE__*/jsx(Table.Cell, {
              colSpan: table.getHeaderGroups().length,
              children: emptyMessage
            })
          }), enableVirtual && /*#__PURE__*/jsxs(Fragment, {
            children: [/*#__PURE__*/jsx(Table.Row, {
              "data-testid": "virtual-padding-top",
              className: 'virtual-padding-top',
              children: /*#__PURE__*/jsx(Table.Cell, {
                style: {
                  height: "".concat(paddingTop, "px")
                }
              })
            }), virtualRows.map(function (row) {
              return /*#__PURE__*/jsx(TableRow, {
                row: table.getRowModel().rows[row.index]
              }, row.index);
            }), /*#__PURE__*/jsx(Table.Row, {
              "data-testid": "virtual-padding-bottom",
              className: 'virtual-padding-bottom',
              children: /*#__PURE__*/jsx(Table.Cell, {
                style: {
                  height: "".concat(paddingBottom, "px")
                }
              })
            })]
          }), !enableVirtual && table.getRowModel().rows.map(function (row) {
            return /*#__PURE__*/jsx(TableRow, {
              row: row
            }, row.id);
          })]
        })]
      }), enablePagination && /*#__PURE__*/jsx("div", {
        style: {
          maxWidth: "".concat(table.getTotalSize(), "px")
        },
        children: /*#__PURE__*/jsx(Pagination, {
          totalItems: table.getFilteredRowModel().rows.length,
          withItemIndicator: true,
          itemsPerPage: page.pageSize,
          onChange: function onChange(e, p) {
            return setPage(function (s) {
              return _objectSpread(_objectSpread({}, s), {}, {
                pageIndex: p - 1
              });
            });
          },
          defaultPage: 1
        })
      })]
    }), debug && enableVirtual && /*#__PURE__*/jsxs("span", {
      children: ["Visible items: ", virtualizer.range.startIndex, " -", ' ', virtualizer.range.endIndex, " / ", rows.length]
    })]
  });
}

export { EdsDataGrid };
